@@ -13,14 +13,14 @@ use File::Basename qw( dirname );
 use File::Path qw( mkpath );
 use File::Copy qw( move );
 use Text::ParseWords qw( shellwords );
-use Test::Stream::Plugin::Subtest ();
-use Test::Stream::Context qw( context );
-use Test::Stream::Exporter;
-default_exports qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic );
-no Test::Stream::Exporter;
+use Test2::Bundle::Extended;
+use Test2::API qw( context run_subtest );
+use base qw( Exporter );
+
+our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 our @aliens;
@@ -138,10 +138,8 @@ sub xs_ok
   if($skip)
   {
     my $ctx = context();
-    $ctx->debug->set_skip('test requires a compiler');
-    $ctx->ok(1, $message);
-    $ctx->ok(1, "$message subtest") if $cb;
-    $ctx->debug->set_skip(undef);
+    $ctx->skip($message, 'test requires a compiler');
+    $ctx->skip("$message subtest", 'test requires a compiler') if $cb;
     $ctx->release;
     return;
   }
@@ -322,12 +320,16 @@ sub xs_ok
   if($cb)
   {
     $cb = sub {
-      Test::Stream::Plugin::Core::skip_all("subtest requires xs success");
+      my $ctx = context();
+      $ctx->plan(0, 'SKIP', "subtest requires xs success");
+      $ctx->release;
     } unless $ok;
-    @_ = ("$message subtest", $cb, $module);
-    goto \&Test::Stream::Plugin::Subtest::subtest_buffered;
+
+    @_ = ("$message subtest", $cb, 1, $module);
+
+    goto \&Test2::API::run_subtest;
   }
-  
+
   $ok;
 }
 
@@ -391,29 +393,27 @@ sub ffi_ok
   
   if($skip)
   {
-    $ok = 1;
-    $ctx->debug->set_skip($skip);
+    $ctx->skip($message, $skip);
   }
-  
-  $ctx->ok($ok, $message);
-  $ctx->diag($_) for @diag;
-  
-  if($skip)
+  else
   {
-    $ok = 0;
-    $ctx->debug->set_skip(undef);
+    $ctx->ok($ok, $message);
   }
+  $ctx->diag($_) for @diag;
   
   $ctx->release;
 
   if($cb)
   {
     $cb = sub {
-      Test::Stream::Plugin::Core::skip_all("subtest requires ffi success");
+      my $ctx = context();
+      $ctx->plan(0, 'SKIP', "subtest requires ffi success");
+      $ctx->release;
     } unless $ok;
 
-    @_ = ("$message subtest", $cb, $ffi);
-    goto \&Test::Stream::Plugin::Subtest::subtest_buffered;
+    @_ = ("$message subtest", $cb, 1, $ffi);
+
+    goto \&Test2::API::run_subtest;
   }
   
   $ok;
@@ -433,13 +433,13 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
 Test commands that come with your Alien:
 
- use Test::Stream -V1;
+ use Test2::Bundle::Extended;
  use Test::Alien;
  use Alien::patch;
  
@@ -454,7 +454,7 @@ Test commands that come with your Alien:
 
 Test that your library works with C<XS>:
 
- use Test::Stream -V1;
+ use Test2::Bundle::Extended;
  use Test::Alien;
  use Alien::Editline;
  
@@ -485,7 +485,7 @@ Test that your library works with C<XS>:
 
 Test that your library works with L<FFI::Platypus>:
 
- use Test::Stream -V1;
+ use Test2::Bundle::Extended;
  use Test::Alien;
  use Alien::LibYAML;
  
@@ -525,9 +525,9 @@ prerequisites are automatically skipped.  For example, L</xs_ok> will automatica
 itself if a compiler is not found, and L</ffi_ok> will automatically skip itself
 if L<FFI::Platypus> is not installed.
 
-B<NOTE>: This module uses L<Test::Stream> instead of the classic L<Test::More>.
+B<NOTE>: This module uses L<Test2> instead of the classic L<Test::More>.
 As of this writing that makes it incompatible with the vast majority of
-testing modules on CPAN.  This will change when/if L<Test::Stream> replaces
+testing modules on CPAN.  This will change when/if L<Test2> replaces
 L<Test::More>.  For the most part testing of L<Alien> modules is done in
 isolation to other testing libraries so that shouldn't be too terrible.
 
@@ -700,7 +700,7 @@ For example:
 
 =over 4
 
-=item L<Test::Stream>
+=item L<Test2>
 
 =item L<Test::Alien::Run>
 
@@ -714,11 +714,7 @@ For example:
 
 =head1 CAVEATS
 
-This module uses L<Test::Stream> instead of L<Test::More>.
-
-Although L<Test::Stream> has gone "stable" it is a relatively new
-module, and thus the interface is probably still in a state of flux
-to some extent.
+This module uses L<Test2> instead of L<Test::More>.
 
 =head1 AUTHOR
 
