@@ -2,24 +2,16 @@ package Test::Alien::CanCompile;
 
 use strict;
 use warnings;
-use Test::Stream::Context qw( context );
-use Test::Stream::Plugin;
+use base 'Test2::Require';
 
 # ABSTRACT: Skip a test file unless a C compiler is available
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
-sub load_ts_plugin
+sub skip
 {
   require ExtUtils::CBuilder;
-  
-  my $skip = !ExtUtils::CBuilder->new->have_compiler;
-  
-  return unless $skip;
-
-  my $ctx = context();
-  $ctx->plan(0, "SKIP", "This test requires a compiler.");
-  $ctx->release;
+  ExtUtils::CBuilder->new->have_compiler ? undef : 'This test requires a compiler.';
 }
 
 1;
@@ -36,11 +28,11 @@ Test::Alien::CanCompile - Skip a test file unless a C compiler is available
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
-This is just a L<Test::Stream> plugin that requires that a compiler
+This is just a L<Test2> plugin that requires that a compiler
 be available.  Otherwise the test will be skipped.
 
 =head1
