@@ -2,23 +2,15 @@ package Test::Alien::CanPlatypus;
 
 use strict;
 use warnings;
-use Test::Stream::Context qw( context );
-use Test::Stream::Plugin;
+use base 'Test2::Require';
 
 # ABSTRACT: Skip a test file unless FFI::Platypus is available
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
-sub load_ts_plugin
+
+sub skip
 {
-  require ExtUtils::CBuilder;
-  
-  my $skip = ! eval { require FFI::Platypus; 1 };
-  
-  return unless $skip;
-
-  my $ctx = context();
-  $ctx->plan(0, "SKIP", "This test requires FFI::Platypus.");
-  $ctx->release;
+  eval { require FFI::Platypus; 1 } ? undef : 'This test requires FFI::Platypus.';
 }
 
 1;
@@ -35,11 +27,11 @@ Test::Alien::CanPlatypus - Skip a test file unless FFI::Platypus is available
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
-This is just a L<Test::Stream> plugin that requires that L<FFI::Platypus>
+This is just a L<Test2> plugin that requires that L<FFI::Platypus>
 be available.  Otherwise the test will be skipped.
 
 =head1
