@@ -2,10 +2,10 @@ package Test::Alien::Run;
 
 use strict;
 use warnings;
-use Test::Stream::Context qw( context );
+use Test2::API qw( context );
 
 # ABSTRACT: Run object
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 sub out    { shift->{out} }
@@ -170,11 +170,11 @@ Test::Alien::Run - Run object
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
- use Test::Stream -V1;
+ use Test2::Extended::Bundle;
  use Test::Alien;
  
  run_ok([ $^X, -e => 'print "some output"; exit 22'])
